@@ -95,8 +95,6 @@ void edascm_init_attrib ();
 void edascm_init_os ();
 void edascm_init_config ();
 void edascm_init_closure (void);
-void edascm_init_log (void);
-void edascm_init_version ();
 void edascm_init_deprecated ();
 void edascm_init_rc ();
 
