@@ -95,16 +95,16 @@ OBJECT*
 s_basic_new_object (int type, char const *prefix);
 
 OBJECT*
-o_object_copy (TOPLEVEL *toplevel, OBJECT *selected);
+o_object_copy (OBJECT *selected);
 
 void
-s_delete_object (TOPLEVEL *toplevel, OBJECT *o_current);
+s_delete_object (OBJECT *o_current);
 
 /* methods */
 
 gboolean
-geda_object_calculate_visible_bounds (TOPLEVEL *toplevel,
-                                      OBJECT *o_current,
+geda_object_calculate_visible_bounds (OBJECT *o_current,
+                                      gboolean include_hidden,
                                       gint *rleft,
                                       gint *rtop,
                                       gint *rright,
@@ -126,15 +126,13 @@ gint
 geda_object_get_visible (const GedaObject *object);
 
 void
-geda_object_rotate (TOPLEVEL *toplevel,
-                    int world_centerx,
+geda_object_rotate (int world_centerx,
                     int world_centery,
                     int angle,
                     OBJECT *object);
 
 void
-geda_object_mirror (TOPLEVEL *toplevel,
-                    int world_centerx,
+geda_object_mirror (int world_centerx,
                     int world_centery,
                     OBJECT *object);
 
@@ -142,17 +140,17 @@ void
 geda_object_set_selectable (GedaObject *object, gboolean selectable);
 
 double
-geda_object_shortest_distance (TOPLEVEL *toplevel,
-                               OBJECT *object,
+geda_object_shortest_distance (OBJECT *object,
                                int x,
-                               int y);
+                               int y,
+                               gboolean include_hidden);
 
 double
-geda_object_shortest_distance_full (TOPLEVEL *toplevel,
-                                    OBJECT *object,
+geda_object_shortest_distance_full (OBJECT *object,
                                     int x,
                                     int y,
-                                    int force_solid);
+                                    int force_solid,
+                                    gboolean include_hidden);
 
 void
 geda_object_translate (GedaObject *object, gint dx, gint dy);
@@ -178,27 +176,26 @@ PAGE*
 o_get_page (OBJECT *object);
 
 OBJECT*
-o_get_parent (TOPLEVEL *toplevel, OBJECT *object);
+o_get_parent (OBJECT *object);
 
 gboolean
-o_is_visible (const TOPLEVEL *toplevel, const OBJECT *object);
+o_is_visible (const OBJECT *object);
 
 void
-o_set_color(TOPLEVEL *toplevel, OBJECT *object, int color);
+o_set_color (OBJECT *object,
+             int color);
 
 void
-o_set_fill_options(TOPLEVEL *toplevel,
-                   OBJECT *o_current,
-                   OBJECT_FILLING type,
-                   int width,
-                   int pitch1,
-                   int angle1,
-                   int pitch2,
-                   int angle2);
+o_set_fill_options (OBJECT *o_current,
+                    OBJECT_FILLING type,
+                    int width,
+                    int pitch1,
+                    int angle1,
+                    int pitch2,
+                    int angle2);
 
 void
-o_set_line_options (TOPLEVEL *toplevel,
-                    OBJECT *o_current,
+o_set_line_options (OBJECT *o_current,
                     OBJECT_END end,
                     OBJECT_TYPE type,
                     int width,
@@ -206,7 +203,8 @@ o_set_line_options (TOPLEVEL *toplevel,
                     int space);
 
 void
-o_set_visibility (TOPLEVEL *toplevel, OBJECT *object, int visibility);
+o_set_visibility (OBJECT *object,
+                  int visibility);
 
 void
 o_add_change_notify (TOPLEVEL *toplevel,
