@@ -1,6 +1,6 @@
-/* gEDA - GPL Electronic Design Automation
- * libgeda - gEDA's library - Scheme API
+/* Lepton EDA library - Scheme API
  * Copyright (C) 2010-2014 Peter Brett <peter@peter-b.co.uk>
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,10 +39,6 @@ TOPLEVEL *edascm_c_current_toplevel ();
 /* Set the #TOPLEVEL fluid in the current dynamic context. */
 void edascm_dynwind_toplevel (TOPLEVEL *toplevel);
 
-/* Set the current #TOPLEVEL temporarily. */
-SCM edascm_c_with_toplevel (TOPLEVEL *toplevel, SCM (*func)(void *),
-                            void *user_data);
-
 /* Create a Guile value from a page structure. */
 SCM edascm_from_page (PAGE *page);
 
