@@ -2,7 +2,6 @@
 SCM scheme_directory(SCM s_path);
 
 /* g_register.c */
-void g_register_libgeda_funcs(void);
 void g_register_libgeda_dirs (void);
 
 /* m_hatch.c */
@@ -30,9 +29,6 @@ void o_emit_change_notify (OBJECT *object);
 void o_selection_select (OBJECT *object);
 void o_selection_unselect (OBJECT *object);
 
-/* s_clib.c */
-void s_clib_init (void);
-
 /* s_conn.c */
 CONN *s_conn_return_new(OBJECT *other_object, int type, int x, int y, int whichone, int other_whichone);
 int s_conn_uniq(GList *conn_list, CONN *input_conn);
