@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -104,6 +104,11 @@ config_get_legacy_mode()
 
 
 
+static EdaConfig* eda_config_get_context_for_file (GFile* path);
+static GFile* eda_config_get_file (EdaConfig* cfg);
+
+
+
 /*! \brief Get filename for system configuration files
  */
 static const gchar*
@@ -237,9 +242,8 @@ eda_config_class_init (EdaConfigClass *klass)
 static void
 eda_config_init (EdaConfig *config)
 {
-  config->priv = G_TYPE_INSTANCE_GET_PRIVATE (config,
-                                              EDA_TYPE_CONFIG,
-                                              EdaConfigPrivate);
+  config->priv =
+    (EdaConfigPrivate*) eda_config_get_instance_private (config);
 
   config->priv->parent = NULL;
   config->priv->keyfile = g_key_file_new ();
@@ -665,7 +669,7 @@ find_project_root (GFile *path)
   return result;
 }
 
-/*! \public \memberof EdaConfig
+/*! \private \memberof EdaConfig
  * \brief Return a local configuration context.
  *
  * Looks for a configuration file named "geda.conf".  If \a path is
@@ -692,7 +696,7 @@ find_project_root (GFile *path)
  * \param [in] path    Path to search for configuration from.
  * \return a local #EdaConfig configuration context for \a path.
  */
-EdaConfig *
+static EdaConfig *
 eda_config_get_context_for_file (GFile *path)
 {
   static gsize initialized = 0;
@@ -739,6 +743,56 @@ eda_config_get_context_for_file (GFile *path)
   return config;
 }
 
+
+
+/*! \brief Get configuration context for a given configuration file.
+ *
+ * \param path     Configuration file path.
+ * \param parent   Context to be used as a parent or NULL.
+ * \param trusted  Whether to mark the context as trusted.
+ *
+ * \return         #EdaConfig configuration context for a file.
+ */
+EdaConfig*
+eda_config_get_anyfile_context (const gchar* path,
+                                EdaConfig*   parent,
+                                gboolean     trusted)
+{
+  g_return_val_if_fail (path != NULL, NULL);
+  g_return_val_if_fail (EDA_IS_CONFIG(parent) || parent == NULL, NULL);
+
+  static gsize initialized = 0;
+  static GHashTable* contexts = NULL;
+  GFile* file = g_file_new_for_path (path);
+
+  if (g_once_init_enter (&initialized))
+  {
+    contexts = g_hash_table_new_full (g_file_hash,
+                                      (GEqualFunc) g_file_equal,
+                                      g_object_unref,
+                                      g_object_unref);
+    g_once_init_leave (&initialized, 1);
+  }
+
+  EdaConfig* cfg = EDA_CONFIG (g_hash_table_lookup (contexts, file));
+  if (cfg == NULL)
+  {
+    gpointer obj = g_object_new (EDA_TYPE_CONFIG,
+                                 "file",    file,
+                                 "parent",  parent,
+                                 "trusted", trusted,
+                                 NULL);
+    cfg = EDA_CONFIG (obj);
+    g_hash_table_insert (contexts, g_object_ref (file), cfg);
+  }
+
+  g_object_unref (file);
+  return cfg;
+
+} /* eda_config_get_anyfile_context() */
+
+
+
 /*! \public \memberof EdaConfig
  * \brief Return a local configuration context.
  *
@@ -777,7 +831,7 @@ eda_config_get_context_for_path (const gchar *path)
   return config;
 }
 
-/*! \public \memberof EdaConfig
+/*! \private \memberof EdaConfig
  * \brief Return underlying filename for configuration context.
  *
  * Return a GFile for the configuration file associated with the
@@ -788,7 +842,7 @@ eda_config_get_context_for_path (const gchar *path)
  * \param cfg  Configuration context.
  * \return Configuration file for \a cfg.
  */
-GFile *
+static GFile *
 eda_config_get_file (EdaConfig *cfg)
 {
   g_return_val_if_fail (EDA_IS_CONFIG (cfg), NULL);
