@@ -1,7 +1,7 @@
 /* Lepton EDA library - Scheme API
  * Copyright (C) 2013-2014 Peter Brett <peter@peter-b.co.uk>
  * Copyright (C) 2013-2016 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -102,9 +102,8 @@ edascm_hook_proxy_init (EdascmHookProxy *proxy)
 {
   SCM proc = SCM_BOOL_F;
 
-  proxy->priv = G_TYPE_INSTANCE_GET_PRIVATE (proxy,
-                                             EDASCM_TYPE_HOOK_PROXY,
-                                             EdascmHookProxyPrivate);
+  proxy->priv =
+    (EdascmHookProxyPrivate*) edascm_hook_proxy_get_instance_private (proxy);
 
   proxy->priv->hook = SCM_UNDEFINED;
   proxy->priv->closure = SCM_UNDEFINED;
