@@ -1,7 +1,7 @@
 /* Lepton EDA library
  * Copyright (C) 1998-2010 Ales Hvezda
  * Copyright (C) 1998-2015 gEDA Contributors
- * Copyright (C) 2017-2019 Lepton EDA Contributors
+ * Copyright (C) 2017-2020 Lepton EDA Contributors
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -277,7 +277,7 @@ process_error_stack (SCM s_stack, SCM s_key, SCM s_args, GError **err) {
   scm_close_output_port (s_port);
 
   /* Send long message to log */
-  s_log_message ("%s", long_message);
+  g_message ("%s", long_message);
 
   /* Populate any GError */
   g_set_error (err, EDA_ERROR, EDA_ERROR_SCHEME, "%s", short_message);
