@@ -139,7 +139,7 @@ g_rc_parse_file (TOPLEVEL *toplevel, const gchar *rcfile,
   scm_dynwind_end ();
 
   if (status) {
-    s_log_message (_("Loaded RC file [%1$s]"), name_norm);
+    g_message (_("Loaded RC file [%1$s]"), name_norm);
   } else {
     /* Copy tmp_err into err, with a prefixed message. */
     g_propagate_prefixed_error (err, tmp_err,
@@ -274,7 +274,7 @@ g_rc_parse__process_error (GError **err, const gchar *pname)
   if (*err == NULL) {
     const gchar *msgl =
       _("ERROR: An unknown error occurred while parsing configuration files.");
-    s_log_message ("%1$s", msgl);
+    g_message ("%1$s", msgl);
     fprintf(stderr, "%1$s\n", msgl);
 
   } else {
@@ -285,7 +285,7 @@ g_rc_parse__process_error (GError **err, const gchar *pname)
       return;
     }
 
-    s_log_message (_("ERROR: %1$s"), (*err)->message);
+    g_message (_("ERROR: %1$s"), (*err)->message);
     fprintf (stderr, _("ERROR: %1$s\n"), (*err)->message);
   }
 
@@ -311,47 +311,21 @@ g_rc_parse__process_error (GError **err, const gchar *pname)
  * on application startup or when there is no chance of data loss from
  * an unexpected exit().
  *
- * \param [in] toplevel  The current #TOPLEVEL structure.
  * \param [in] pname     The name of the application (usually argv[0]).
  * \param [in] rcname    RC file basename, or NULL.
  * \param [in] rcfile    Specific RC file path, or NULL.
  */
 void
-g_rc_parse (TOPLEVEL *toplevel, const gchar *pname,
-            const gchar *rcname, const gchar *rcfile)
+g_rc_parse (const gchar *pname,
+            const gchar *rcname,
+            const gchar *rcfile)
 {
+  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   g_rc_parse_handler (toplevel, rcname, rcfile,
                       (ConfigParseErrorFunc) g_rc_parse__process_error,
                       (void *) pname);
 }
 
-/*! \brief General RC file parsing Scheme procedure.
- * \par Function Description
- * Analog of g_rc_parse() for using in Scheme.
- *
- * \param [in] pname_s   The name of the application (Scheme string).
- * \param [in] rcname    RC file basename (Scheme string).
- * \return SCM_UNSPECIFIED.
- */
-SCM
-g_rc_parse_rc (SCM pname_s, SCM rcname_s)
-{
-  gchar *pname = NULL;
-  gchar *rcname = NULL;
-  TOPLEVEL *toplevel = NULL;
-
-  SCM_ASSERT (scm_is_string (pname_s), pname_s,
-              SCM_ARG1, "parse-rc");
-  SCM_ASSERT (scm_is_string (rcname_s), rcname_s,
-              SCM_ARG2, "parse-rc");
-
-  pname = scm_to_utf8_string (pname_s);
-  rcname = scm_to_utf8_string (rcname_s);
-  toplevel = edascm_c_current_toplevel ();
-
-  g_rc_parse (toplevel, pname, rcname, NULL);
-  return SCM_UNSPECIFIED;
-}
 
 /*! \brief General RC file parsing function.
  * \par Function Description
@@ -411,204 +385,6 @@ g_rc_parse_handler (TOPLEVEL *toplevel,
 #undef HANDLER_DISPATCH
 }
 
-/*! \brief
- *  \par Function Description
- *
- *  \param [in] path 
- *  \param [in] name Optional descriptive name for library directory.
- *  \return SCM_BOOL_T on success, SCM_BOOL_F otherwise.
- */
-
-SCM_DEFINE (component_library, "%component-library", 1, 1, 0,
-            (SCM path, SCM name),
-            "Adds the component library with specified PATH and NAME to the list of component libraries.")
-{
-  gchar *string;
-  char *temp;
-  char *namestr = NULL;
-
-  SCM_ASSERT (scm_is_string (path), path,
-              SCM_ARG1, s_component_library);
-
-  scm_dynwind_begin ((scm_t_dynwind_flags) 0);
-  if (!scm_is_eq (name, SCM_UNDEFINED)) {
-    SCM_ASSERT (scm_is_string (name), name,
-		SCM_ARG2, s_component_library);
-    namestr = scm_to_utf8_string (name);
-    scm_dynwind_free(namestr);
-  }
-
-  /* take care of any shell variables */
-  temp = scm_to_utf8_string (path);
-  string = s_expand_env_variables (temp);
-  scm_dynwind_unwind_handler (g_free, string, SCM_F_WIND_EXPLICITLY);
-  free (temp);
-
-  /* invalid path? */
-  if (!g_file_test (string, G_FILE_TEST_IS_DIR)) {
-    fprintf(stderr,
-            _("Invalid path [%1$s] passed to component-library\n"),
-            string);
-    scm_dynwind_end();
-    return SCM_BOOL_F;
-  }
-
-  if (g_path_is_absolute (string)) {
-    s_clib_add_directory (string, namestr);
-  } else {
-    gchar *cwd = g_get_current_dir ();
-    gchar *temp;
-    temp = g_build_filename (cwd, string, NULL);
-    s_clib_add_directory (temp, namestr);
-    g_free(temp);
-    g_free(cwd);
-  }
-
-  scm_dynwind_end();
-  return SCM_BOOL_T;
-}
-
-/*! \brief Guile callback for adding library commands.
- *  \par Function Description
- *  Callback function for the "component-library-command" Guile
- *  function, which can be used in the rc files to add a command to
- *  the component library.
- *
- *  \param [in] listcmd command to get a list of symbols
- *  \param [in] getcmd  command to get a symbol from the library
- *  \param [in] name    Optional descriptive name for component source.
- *  \return SCM_BOOL_T on success, SCM_BOOL_F otherwise.
- */
-SCM_DEFINE (component_library_command, "%component-library-command", 3, 0, 0,
-            (SCM listcmd, SCM getcmd, SCM name),
-            "Creates a component library source called NAME (the third"
-"argument) driven by two user commands: LIST-COMMAND (the first"
-"argument) and GET-COMMAND (the second argument). The list command"
-"should return a list of component names in the source.  The get"
-"command should return symbol contents by specified component name."
-"Both commands should output their results to stdout.")
-{
-  const CLibSource *src;
-  gchar *lcmdstr, *gcmdstr;
-  char *tmp_str, *namestr;
-
-  SCM_ASSERT (scm_is_string (listcmd), listcmd, SCM_ARG1, 
-              s_component_library_command);
-  SCM_ASSERT (scm_is_string (getcmd), getcmd, SCM_ARG2, 
-              s_component_library_command);
-  SCM_ASSERT (scm_is_string (name), name, SCM_ARG3, 
-              s_component_library_command);
-
-  scm_dynwind_begin ((scm_t_dynwind_flags) 0);
-
-  /* take care of any shell variables */
-  /*! \bug this may be a security risk! */
-  tmp_str = scm_to_utf8_string (listcmd);
-  lcmdstr = s_expand_env_variables (tmp_str);
-  scm_dynwind_unwind_handler (g_free, lcmdstr, SCM_F_WIND_EXPLICITLY);
-  free (tmp_str); /* this should stay as free (allocated from guile) */
-
-  /* take care of any shell variables */
-  /*! \bug this may be a security risk! */
-  tmp_str = scm_to_utf8_string (getcmd);
-  gcmdstr = s_expand_env_variables (tmp_str);
-  scm_dynwind_unwind_handler (g_free, gcmdstr, SCM_F_WIND_EXPLICITLY);
-  free (tmp_str); /* this should stay as free (allocated from guile) */
-
-  namestr = scm_to_utf8_string (name);
-
-  src = s_clib_add_command (lcmdstr, gcmdstr, namestr);
-
-  free (namestr); /* this should stay as free (allocated from guile) */
-
-  scm_dynwind_end();
-
-  if (src != NULL) {
-    return SCM_BOOL_T;
-  }
-
-  return SCM_BOOL_F;
-}
-
-/*! \brief Guile callback for adding library functions.
- *  \par Function Description
- *  Callback function for the "component-library-funcs" Guile
- *  function, which can be used in the rc files to add a set of Guile
- *  procedures for listing and generating symbols.
- *
- *  \param [in] listfunc A Scheme procedure which takes no arguments
- *                       and returns a Scheme list of component names.
- *  \param [in] getfunc A Scheme procedure which takes a component
- *                      name as an argument and returns a symbol
- *                      encoded in a string in gEDA format, or the \b
- *                      \#f if the component name is unknown.
- *  \param [in] name    A descriptive name for this component source.
- *
- *  \returns SCM_BOOL_T on success, SCM_BOOL_F otherwise.
- */
-
-SCM_DEFINE (component_library_funcs, "%component-library-funcs", 3, 0, 0,
-            (SCM listfunc, SCM getfunc, SCM name),
-            "Creates a component library source called NAME (the third"
-"argument) driven by two user Scheme procedures: LIST-FUNCTION (the"
-"first argument) and GET-FUNCTION (the second argument). The list"
-"function should return a Scheme list of component names in the"
-"source.  The get function should return symbol contents by"
-"specified component name as a Scheme string or #f, if there is no"
-"such name in the list.")
-{
-  char *namestr;
-  SCM result = SCM_BOOL_F;
-
-  SCM_ASSERT (scm_is_true (scm_procedure_p (listfunc)), listfunc, SCM_ARG1,
-              s_component_library_funcs);
-  SCM_ASSERT (scm_is_true (scm_procedure_p (getfunc)), getfunc, SCM_ARG2,
-              s_component_library_funcs);
-  SCM_ASSERT (scm_is_string (name), name, SCM_ARG3, 
-              s_component_library_funcs);
-
-  namestr = scm_to_utf8_string (name);
-
-  if (s_clib_add_scm (listfunc, getfunc, namestr) != NULL) {
-    result = SCM_BOOL_T;
-  }
-
-  free (namestr);
-  return result;
-}
-
-/*!
- * \brief Get the name of the RC filename being evaluated.
- * \par Function Description
- *
- * Creates a Guile stack object, extracts the topmost frame from that
- * stack and gets the sourcefile name.
- *
- * \returns If the interpreter can resolve the filename, returns a
- * Scheme object with the full path to the RC file, otherwise #f
- */
-SCM
-g_rc_rc_filename()
-{
-  SCM stack, frame, source;
-
-  stack = scm_make_stack (SCM_BOOL_T, SCM_EOL);
-  if (scm_is_false (stack)) {
-    return SCM_BOOL_F;
-  }
-
-  frame = scm_stack_ref (stack, scm_from_int(0));
-  if (scm_is_false (frame)) {
-    return SCM_BOOL_F;
-  }
-
-  source = scm_frame_source (frame);
-  if (scm_is_false (source)) {
-    return SCM_BOOL_F;
-  }
-
-  return scm_source_property (source, scm_sym_filename);
-}
 
 /*! \brief Add a directory to the Guile load path.
  * \par Function Description
@@ -646,35 +422,6 @@ SCM_DEFINE (scheme_directory,"%scheme-directory", 1, 0, 0,
   return SCM_BOOL_T;
 }
 
-/*! \todo Finish function description!!!
- *  \brief
- *  \par Function Description
- *
- *  \return SCM_BOOL_T always.
- */
-SCM_DEFINE (reset_component_library, "%reset-component-library", 0, 0, 0,
-            (void), "Reset component library and initialise it to an empty list.")
-{
-  s_clib_init();
-  
-  return SCM_BOOL_T;
-}
-
-SCM_DEFINE (print_color_map, "%print-color-map", 0, 1, 0,
-            (SCM scm_map), "Set or view current print color map.")
-{
-  if (scm_is_eq (scm_map, SCM_UNDEFINED)) {
-    return s_color_map_to_scm (print_colors);
-  }
-
-  SCM_ASSERT (scm_is_true (scm_list_p (scm_map)),
-              scm_map, SCM_ARG1, s_print_color_map);
-
-  s_color_map_from_scm (print_colors, scm_map, "print-color-map");
-  return SCM_BOOL_T;
-}
-
-
 
 /*! \brief Load cache configuration data.
  *
@@ -722,12 +469,7 @@ init_module_lepton_core_rc (void *unused)
   #include "g_rc.x"
 
   /* Add them to the module's public definitions. */
-  scm_c_export (s_component_library,
-                s_component_library_command,
-                s_component_library_funcs,
-                s_print_color_map,
-                s_reset_component_library,
-                s_scheme_directory,
+  scm_c_export (s_scheme_directory,
                 NULL);
 }
 
