@@ -315,15 +315,15 @@ o_box_read (const char buf[],
   }
 
   if (width == 0 || height == 0) {
-    s_log_message (_("Found a zero width/height box "
-                     "[ %1$c %2$d %3$d %4$d %5$d %6$d ]"),
-                   type, x1, y1, width, height, color);
+    g_message (_("Found a zero width/height box "
+                 "[ %1$c %2$d %3$d %4$d %5$d %6$d ]"),
+               type, x1, y1, width, height, color);
   }
 
-  if (color < 0 || color > MAX_COLORS) {
-    s_log_message (_("Found an invalid color [ %1$s ]"), buf);
-    s_log_message (_("Setting color to default color."));
-    color = DEFAULT_COLOR;
+  if (!color_id_valid (color)) {
+    g_message (_("Found an invalid color [ %1$s ]"), buf);
+    g_message (_("Setting color to default color."));
+    color = default_color_id();
   }
 
   /*! \note
