@@ -194,10 +194,10 @@ o_path_read (const char *first_line,
   /*
    * Checks if the required color is valid.
    */
-  if (color < 0 || color > MAX_COLORS) {
-    s_log_message (_("Found an invalid color [ %1$s ]"), first_line);
-    s_log_message (_("Setting color to default color."));
-    color = DEFAULT_COLOR;
+  if (!color_id_valid (color)) {
+    g_message (_("Found an invalid color [ %1$s ]"), first_line);
+    g_message (_("Setting color to default color."));
+    color = default_color_id();
   }
 
   /*
