@@ -106,18 +106,19 @@ int s_conn_uniq(GList * conn_list, CONN * input_conn)
  *  \par Function Description
  *  This function removes the OBJECT <b>to_remove</b> from the connection
  *  list of the OBJECT <b>other_object</b>.
- *  \param toplevel (currently not used)
+ *
  *  \param other_object OBJECT from that the to_remove OBJECT needs to be removed
  *  \param to_remove OBJECT to remove
  *  \return TRUE if a connection has been deleted, FALSE otherwise
  */
-int s_conn_remove_other (TOPLEVEL *toplevel, OBJECT *other_object,
-                         OBJECT *to_remove)
+int
+s_conn_remove_other (OBJECT *other_object,
+                     OBJECT *to_remove)
 {
     GList *c_current = NULL;
     CONN *conn = NULL;
 
-    o_emit_pre_change_notify (toplevel, other_object);
+    o_emit_pre_change_notify (other_object);
 
     c_current = other_object->conn_list;
     while (c_current != NULL) {
@@ -153,7 +154,7 @@ int s_conn_remove_other (TOPLEVEL *toplevel, OBJECT *other_object,
 	c_current = g_list_next(c_current);
     }
 
-    o_emit_change_notify (toplevel, other_object);
+    o_emit_change_notify (other_object);
 
     return (FALSE);
 }
@@ -162,11 +163,11 @@ int s_conn_remove_other (TOPLEVEL *toplevel, OBJECT *other_object,
  *  \par Function Description
  *  This function removes all connections from and to the OBJECT
  *  <b>to_remove</b>.
- *  \param toplevel  The TOPLEVEL structure
+ *
  *  \param to_remove OBJECT to unconnected from all other objects
  */
 void
-s_conn_remove_object_connections (TOPLEVEL *toplevel, OBJECT *to_remove)
+s_conn_remove_object_connections (OBJECT *to_remove)
 {
   GList *c_iter;
   CONN *conn;
@@ -184,7 +185,7 @@ s_conn_remove_object_connections (TOPLEVEL *toplevel, OBJECT *to_remove)
 
         /* keep calling this till it returns false (all refs removed) */
         /* there is NO body to this while loop */
-        while (s_conn_remove_other (toplevel, conn->other_object, to_remove));
+        while (s_conn_remove_other (conn->other_object, to_remove));
 
         c_iter->data = NULL;
         g_free (conn);
@@ -198,7 +199,7 @@ s_conn_remove_object_connections (TOPLEVEL *toplevel, OBJECT *to_remove)
     case OBJ_PLACEHOLDER:
       for (iter = to_remove->component->prim_objs; iter != NULL; iter = g_list_next (iter)) {
         o_current = (OBJECT*) iter->data;
-        s_conn_remove_object_connections (toplevel, o_current);
+        s_conn_remove_object_connections (o_current);
       }
       break;
   }
@@ -340,12 +341,8 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
   OBJECT *found;
   int j, k;
   OBJECT *component, *other_component;
-  TOPLEVEL *toplevel;
 
-  toplevel = page->toplevel;
-  g_return_if_fail (toplevel != NULL);
-
-  component = o_get_parent (toplevel, object);
+  component = o_get_parent (object);
 
   /* loop over all connectible objects */
   for (object_list = page->connectible_list;
@@ -356,7 +353,7 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
     if (object == other_object)
       continue;
 
-    other_component = o_get_parent (toplevel, other_object);
+    other_component = o_get_parent (other_object);
 
     /* An object inside a symbol can only be connected up to another
      * object if they are (a) both inside the same object, or (b)
@@ -399,7 +396,7 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
             object->line->y[j] == other_object->line->y[k] &&
             check_direct_compat (object, other_object)) {
 
-          o_emit_pre_change_notify (toplevel, other_object);
+          o_emit_pre_change_notify (other_object);
 
           add_connection (object, other_object, CONN_ENDPOINT,
                           other_object->line->x[k],
@@ -409,7 +406,7 @@ static void s_conn_update_line_object (PAGE* page, OBJECT *object)
                           object->line->x[j],
                           object->line->y[j], k, j);
 
-          o_emit_change_notify (toplevel, other_object);
+          o_emit_change_notify (other_object);
         }
       }
     }
