@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /*!
@@ -190,7 +190,6 @@ SCM_DEFINE (attach_attrib_x, "%attach-attrib!", 2, 0, 0,
   SCM_ASSERT (edascm_is_object_type (attrib_s, OBJ_TEXT), attrib_s,
               SCM_ARG2, s_attach_attrib_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
   OBJECT *attrib = edascm_to_object (attrib_s);
 
@@ -219,9 +218,9 @@ SCM_DEFINE (attach_attrib_x, "%attach-attrib!", 2, 0, 0,
   }
 
   /* Carry out the attachment */
-  o_emit_pre_change_notify (toplevel, attrib);
-  o_attrib_attach (toplevel, attrib, obj, TRUE);
-  o_emit_change_notify (toplevel, attrib);
+  o_emit_pre_change_notify (attrib);
+  o_attrib_attach (attrib, obj, TRUE);
+  o_emit_change_notify (attrib);
 
   o_page_changed (obj);
 
@@ -251,7 +250,6 @@ SCM_DEFINE (detach_attrib_x, "%detach-attrib!", 2, 0, 0,
   SCM_ASSERT (edascm_is_object_type (attrib_s, OBJ_TEXT), attrib_s,
               SCM_ARG2, s_detach_attrib_x);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (obj_s);
   OBJECT *attrib = edascm_to_object (attrib_s);
 
@@ -268,10 +266,10 @@ SCM_DEFINE (detach_attrib_x, "%detach-attrib!", 2, 0, 0,
   }
 
   /* Detach object */
-  o_emit_pre_change_notify (toplevel, attrib);
-  o_attrib_remove (toplevel, &obj->attribs, attrib);
-  o_set_color (toplevel, attrib, DETACHED_ATTRIBUTE_COLOR);
-  o_emit_change_notify (toplevel, attrib);
+  o_emit_pre_change_notify (attrib);
+  o_attrib_remove (&obj->attribs, attrib);
+  o_set_color (attrib, DETACHED_ATTRIBUTE_COLOR);
+  o_emit_change_notify (attrib);
 
   o_page_changed (obj);
 
@@ -294,10 +292,9 @@ SCM_DEFINE (promotable_attribs, "%promotable-attribs", 1, 0, 0,
   SCM_ASSERT (edascm_is_object_type (component_s, OBJ_COMPONENT), component_s,
               SCM_ARG1, s_promotable_attribs);
 
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
   OBJECT *obj = edascm_to_object (component_s);
 
-  GList *lst = o_component_get_promotable (toplevel, obj, FALSE);
+  GList *lst = o_component_get_promotable (obj, FALSE);
 
   return edascm_from_object_glist (lst);
 }
