@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 /*!
@@ -236,7 +236,6 @@ SCM_DEFINE (page_append_x, "%page-append!", 2, 0, 0,
 
   PAGE *page = edascm_to_page (page_s);
   OBJECT *obj = edascm_to_object (obj_s);
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
 
   /* Check that the object isn't already attached to something. */
   PAGE *curr_page = o_get_page (obj);
@@ -251,9 +250,9 @@ SCM_DEFINE (page_append_x, "%page-append!", 2, 0, 0,
 
   /* Object cleanup now managed by C code. */
   edascm_c_set_gc (obj_s, 0);
-  o_emit_pre_change_notify (toplevel, obj);
-  s_page_append (toplevel, page, obj);
-  o_emit_change_notify (toplevel, obj);
+  o_emit_pre_change_notify (obj);
+  s_page_append (page, obj);
+  o_emit_change_notify (obj);
   page->CHANGED = 1; /* Ugh. */
 
   return page_s;
@@ -281,7 +280,6 @@ SCM_DEFINE (page_remove_x, "%page-remove!", 2, 0, 0,
 
   PAGE *page = edascm_to_page (page_s);
   OBJECT *obj = edascm_to_object (obj_s);
-  TOPLEVEL *toplevel = edascm_c_current_toplevel ();
 
   /* Check that the object is not attached to something else. */
   PAGE *curr_page = o_get_page (obj);
@@ -308,12 +306,12 @@ SCM_DEFINE (page_remove_x, "%page-remove!", 2, 0, 0,
 
   if (curr_page == NULL) return obj_s;
 
-  o_emit_pre_change_notify (toplevel, obj);
-  s_page_remove (toplevel, page, obj);
+  o_emit_pre_change_notify (obj);
+  s_page_remove (page, obj);
   page->CHANGED = 1; /* Ugh. */
   /* If the object is currently selected, unselect it. */
-  o_selection_remove (toplevel, page->selection_list, obj);
-  o_emit_change_notify (toplevel, obj);
+  o_selection_remove (page->selection_list, obj);
+  o_emit_change_notify (obj);
 
   /* Object cleanup now managed by Guile. */
   edascm_c_set_gc (obj_s, 1);
@@ -426,7 +424,7 @@ SCM_DEFINE (string_to_page, "%string->page", 2, 0, 0,
   size_t len;
   GError * err = NULL;
   char *str = scm_to_utf8_stringn (str_s, &len);
-  GList *objects = o_read_buffer (toplevel, NULL, str, len,
+  GList *objects = o_read_buffer (page, NULL, str, len,
                                   s_page_get_filename(page), &err);
   free (str);
 
@@ -438,7 +436,7 @@ SCM_DEFINE (string_to_page, "%string->page", 2, 0, 0,
                  _("Parse error: ~s"), scm_list_1 (error_message), SCM_EOL);
   }
 
-  s_page_append_list (toplevel, page, objects);
+  s_page_append_list (page, objects);
 
   return edascm_from_page (page);
 }
