@@ -10,7 +10,7 @@ check_construction ()
   for (count = 0; count < 1000; count++) {
     gint center_x = g_test_rand_int ();
     gint center_y = g_test_rand_int ();
-    gint color = g_test_rand_int_range (0, MAX_COLORS - 1);
+    gint color = g_test_rand_int_range (0, colors_count());
     gint radius = g_test_rand_int_range (0, G_MAXINT);
     gint start_angle = g_test_rand_int_range (0, 359);
     gint sweep_angle = g_test_rand_int_range (0, 360);
@@ -62,7 +62,7 @@ check_accessors ()
   for (count = 0; count < 1000; count++) {
     gint center_x = g_test_rand_int ();
     gint center_y = g_test_rand_int ();
-    gint color = g_test_rand_int_range (0, MAX_COLORS - 1);
+    gint color = g_test_rand_int_range (0, colors_count());
     gint radius = g_test_rand_int_range (0, G_MAXINT);
     gint start_angle = g_test_rand_int_range (0, 359);
     gint sweep_angle = g_test_rand_int_range (0, 360);
@@ -79,7 +79,7 @@ check_accessors ()
 
     center_x = g_test_rand_int ();
     center_y = g_test_rand_int ();
-    color = g_test_rand_int_range (0, MAX_COLORS - 1);
+    color = g_test_rand_int_range (0, colors_count());
     radius = g_test_rand_int_range (0, G_MAXINT);
     start_angle = g_test_rand_int_range (0, 359);
     sweep_angle = g_test_rand_int_range (0, 360);
@@ -118,7 +118,7 @@ check_serialization ()
   for (count = 0; count < 1000; count++) {
     gint center_x = g_test_rand_int ();
     gint center_y = g_test_rand_int ();
-    gint color = g_test_rand_int_range (0, MAX_COLORS - 1);
+    gint color = g_test_rand_int_range (0, colors_count());
     gint radius = g_test_rand_int_range (0, G_MAXINT);
     gint start_angle = g_test_rand_int_range (0, 359);
     gint sweep_angle = g_test_rand_int_range (0, 360);
