@@ -10,7 +10,7 @@ check_construction ()
   for (count = 0; count < 1000; count++) {
     gint center_x = g_test_rand_int ();
     gint center_y = g_test_rand_int ();
-    gint color = g_test_rand_int_range (0, MAX_COLORS - 1);
+    gint color = g_test_rand_int_range (0, colors_count());
     gint radius = g_test_rand_int_range (0, G_MAXINT);
 
     GedaObject *object0 = geda_circle_object_new (color,
@@ -54,7 +54,7 @@ check_accessors ()
   for (count = 0; count < 1000; count++) {
     gint center_x = g_test_rand_int ();
     gint center_y = g_test_rand_int ();
-    gint color = g_test_rand_int_range (0, MAX_COLORS - 1);
+    gint color = g_test_rand_int_range (0, colors_count());
     gint radius = g_test_rand_int_range (0, G_MAXINT);
 
     GedaObject *object0 = geda_circle_object_new (color,
@@ -67,7 +67,7 @@ check_accessors ()
 
     center_x = g_test_rand_int ();
     center_y = g_test_rand_int ();
-    color = g_test_rand_int_range (0, MAX_COLORS - 1);
+    color = g_test_rand_int_range (0, colors_count());
     radius = g_test_rand_int_range (0, G_MAXINT);
 
     geda_circle_object_set_center_x (object0, center_x);
@@ -100,7 +100,7 @@ check_serialization ()
   for (count = 0; count < 1000; count++) {
     gint center_x = g_test_rand_int ();
     gint center_y = g_test_rand_int ();
-    gint color = g_test_rand_int_range (0, MAX_COLORS - 1);
+    gint color = g_test_rand_int_range (0, colors_count());
     gint radius = g_test_rand_int_range (0, G_MAXINT);
 
     GedaObject *object0 = geda_circle_object_new (color,
