@@ -33,7 +33,7 @@ exec @GUILE@ -s "$0" "$@"
                 "liblepton_init")
 
 (define libgtk (dynamic-link "@LIBGTK@"))
-(define libleptonattrib (dynamic-link "libleptonattrib"))
+(define libleptonattrib (dynamic-link "@LIBLEPTONATTRIB@"))
 
 (define gtk-init
   (pointer->procedure
