@@ -328,6 +328,8 @@ void s_toplevel_delete_attrib_col() {
   g_debug ("s_toplevel_delete_attrib_col: "
            "Checks were OK, now do real work\n");
 
+  TABLE** table_new = NULL;
+
   /*  Rebuild the gattrib-specific data structures  */
   switch (cur_page) {
 
@@ -337,9 +339,6 @@ void s_toplevel_delete_attrib_col() {
      *  attrib.  However, that is difficult.  Therefore, I will just
      *  destroy the old table and recreate it for now. */
 
-    s_table_destroy(sheet_head->component_table, 
-		    sheet_head->comp_count, sheet_head->comp_attrib_count);
-
     /*  Get name (label) of the col to delete from the gtk sheet */
     attrib_name = g_strdup( gtk_sheet_column_button_get_label(sheet, mincol) );
     
@@ -351,23 +350,37 @@ void s_toplevel_delete_attrib_col() {
       fprintf (stderr, _("Can't get attrib name\n"));
       return;
     }
+
+    /* Make a copy of the TABLE array, minus data in col to delete:
+    */
+    table_new = s_table_copy (sheet_head->component_table,
+                              mincol,
+                              sheet_head->comp_count,
+                              sheet_head->comp_attrib_count);
     
+    /* Destroy the current TABLE array:
+    */
+    s_table_destroy(sheet_head->component_table,
+        sheet_head->comp_count, sheet_head->comp_attrib_count);
+
     g_debug ("s_toplevel_delete_attrib_col: "
             "Before deleting comp attrib: comp_attrib_count = %d\n",
             sheet_head->comp_attrib_count);
+
     s_string_list_delete_item(&(sheet_head->master_comp_attrib_list_head),
 			      &(sheet_head->comp_attrib_count), 
 			      attrib_name);
     s_string_list_sort_master_comp_attrib_list(); /* this renumbers list also */
+
     g_free(attrib_name);
     
     g_debug ("s_toplevel_delete_attrib_col: "
             "Just updated comp_attrib string list: new comp_attrib_count = %d\n",
             sheet_head->comp_attrib_count);
 
-    /* Now create new table with new attrib count*/
-    sheet_head->component_table = s_table_new(sheet_head->comp_count, 
-					      sheet_head->comp_attrib_count);
+    /* Use the copy made above as the current TABLE array:
+    */
+    sheet_head->component_table = table_new;
 
     g_debug ("s_toplevel_delete_attrib_col: Updated SHEET_DATA info.\n");
     break;
