@@ -1,8 +1,9 @@
 #!/bin/sh
+export LANG=C
 
 INPUT=$1
 rundir=${abs_builddir}/run
-SYMCHECK=${abs_top_builddir}/symcheck/scheme/lepton-symcheck
+SYMCHECK=${abs_top_builddir}/utils/scripts/lepton-symcheck
 # Hack to enable `make distcheck'
 
 # create temporary run directory and required subdirs
